==> oeg_infotech-1.3-py2-none-any.whl: oeg_infotech/codes/feature.py <==
# coding: utf-8
"""
Pipeline features
"""


class Feature:  # pylint: disable=old-style-class,no-init,too-few-public-methods
    """
    codes for detected features
    """
    ANOMALY = '990006537198'  # 990006537148 ANOM Аномалия 990006537148 OTHE
    NESVAR_STYK = '990006537195'  # 990006537148 ANOM Несваренный стык патрона 990006537195 UWCA
    POTERYA_CONTACTA = '990006548776'  # 990006537148 ANOM Аномалия 990006537148 OTHE
    EXCENTR_CASE = '990006537194'  # 990006537148 ANOM Эксцентричный патрон 990006537194 EXCA
    ANOMAL_KOLTSEVOGO = '990006537187'  # 990006537148 ANOM Аномалия кольцевого шва 990006537187 GWAN
    ANOMAL_OBLTSOVKI = '990006537186'  # 990006537148 ANOM Аномалия кольцевого шва 990006537187 GWAN
    CORROZ_KOLTSEVOGO = '990006537185'  # 990006537148 ANOM Аномалия кольцевого шва 990006537187 GWAN
    NEPROVAR_UTYAZH = '990006537184'  # 990006537148 ANOM Аномалия кольцевого шва 990006537187 GWAN
    NO_USILEN_KOLTSEVOGO = '990008404344'  # 990006537148 ANOM Аномалия кольцевого шва 990006537187 GWAN
    PODKLAD_KOLTSO = '990006548775'  # 330000002264 OTHE Другое 330000002264 -
    PODREZ = '990006537148'  # 990006537148 ANOM Аномалия кольцевого шва 990006537187 GWAN
    PRAVKA_KROMOK = '990006548774'  # 990006537148 ANOM Аномалия кольцевого шва 990006537187 GWAN
    PROVIS_KORNYA = '990007322160'  # 990006537148 ANOM Аномалия кольцевого шва 990006537187 GWAN
    SMESCHENIE_KROMOK = '990007289509'  # 990006537148 ANOM Аномалия кольцевого шва 990006537187 GWAN
    VNUTRI_SHOV_DEFEKT = '6907237'  # 990006537148 ANOM Аномалия кольцевого шва 990006537187 GWAN
    PODGIB_KROMKY = '6907241'  # 990006537148 ANOM Аномалия кольцевого шва 990006537187 GWAN
    ANOMAL_PRODOLNOGO = '990006537188'  # 990006537148 ANOM Аномалия продольного шва 990006537188 LWAN
    VYSHLIFOVKA_PRODOLNOGO = '990007322148'  # 990006537148 ANOM Аномалия продольного шва 990006537188 LWAN
    FORMA_PRODOLNOGO = '990007322161'  # 990006537148 ANOM Аномалия продольного шва 990006537188 LWAN
    ANOMAL_SPIRALNOGO = '990006537189'  # 990006537148 ANOM Аномалия спирального шва 990006537189 SWAN
    VYSHLIFOVKA_SPIRALNOGO = '990007322164'  # 990006537148 ANOM Аномалия спирального шва 990006537189 SWAN
    FORMA_SPIRALNOGO = '990007322162'  # 990006537148 ANOM Аномалия спирального шва 990006537189 SWAN
    DENT = '230000190556'  # 990006537148 ANOM Вмятина 230000190556 DENT
    DENT_METAL_LOSS = '990006537191'  # 990006537148 ANOM Вмятина с дефектами потери металла 990006537191 DEML
    VNUTRYSTEN_RASSLOENIE = '990006537192'  # 990006537148 ANOM Внутристенное расслоение 990006537192 LAMI
    GOFRA = '990006537193'  # 990006537148 ANOM Гофра 990006537147 WRIN
    FACTORY_DEFEKT = '990006537199'  # 990006537148 ANOM Заводской дефект 990006537199 MIAN
    METALL_DEFEKT = '990004698865'  # 990006537148 ANOM Заводской дефект 990006537199 MIAN
    VYSHLIFOVKA = '990004698880'  # 990006537148 ANOM Вышлифовка 990004698880 GRIN
    ZONE_VERT_CRACKS = '990007322158'  # 990006537148 ANOM Зона поперечных трещин 990007322158 CSCC
    ZONE_HOR_CRACKS = '990004698849'  # 990006537148 ANOM Зона продольных трещин 990004698849 SCC
    ZONE_CORROZ = '990006537202'  # 990006537148 ANOM Кластер коррозии 990006537152 COCL
    CAVERNA = '990007289502'  # 990006537148 ANOM Коррозия 990007289504 CORR
    CORROZ = '990007289504'  # 990006537148 ANOM Коррозия 990007289504 CORR
    KANAVKA_VERT = '990004698855'  # 990006537148 ANOM Коррозия 990007289504 CORR
    METALL_LOSS = '990004698869'  # 990006537148 ANOM Коррозия 990007289504 CORR
    KANAVKA_HOR = '990004698848'  # 990006537148 ANOM Коррозия 990007289504 CORR
    POINT_CORROZ = '30000179093'  # 990006537148 ANOM Коррозия 990007289504 CORR
    MECHANICAL_DEFEKT = '3760623'  # 990006537148 ANOM Механическое повреждение 3760623 ARTD
    RANDOM_ARC = '990006537209'  # 990006537148 ANOM Случайная дуга 990006537209 ARCS
    RASSL_NO_POVERHNOST = '990006537210'  # 990006537148 ANOM Расслоение с выходом на поверхность 990006537210 LAMI
    ZAVARKA = '990006537213'  # 990006537148 ANOM Технологический дефект 240000166873 TECH
    ZAVARKA_OTVERST = '990006537212'  # 990006537148 ANOM Технологический дефект 240000166873 TECH
    TECHNOLOGY_DEFEKT = '240000166873'  # 990006537148 ANOM Технологический дефект 240000166873 TECH
    CRACK_VERT_SHOV = '990006537214'  # 990006537148 ANOM Трещина на кольцевом шве 990006537214 GWCR
    CRACK_HOR_SHOV = '990007322154'  # 990006537148 ANOM Трещина на продольном шве 990007322154 LWCR
    CRACK_SPIRAL_SHOV = '990007322159'  # 990006537148 ANOM Трещина на спиральном шве 990007322159 SWCR
    NESPLOSHNOST_PT = '990006548777'  # 990006537148 ANOM Трещиноподобный дефект 990006537159 CRAC
    CRACK_VERT = '990004698875'  # 990006537148 ANOM Трещиноподобный дефект 990006537159 CRAC
    CRACK_HOR = '990006537215'  # 990006537148 ANOM Трещиноподобный дефект 990006537159 CRAC
    OVAL = '990006537217'  # 990006537148 ANOM Овализация 990006537217 OVAL
    METALL_OUT = '990006537218'  # 990006536987 ADME Металл снаружи 990006537218 TMTM
    ISOL_STYK = '990006537366'  # 990006537366 ISOL Изоляционный стык 990006537366 -
    CURVE_INSERT = '990006537221'  # 330000002264 OTHE Другое 330000002264 -
    SEGMENT_INSERT = '990006537219'  # 330000002264 OTHE Другое 330000002264 -
    HOMUT = '990006537362'  # 990006536987 ADME Хомут 990006537362 CLAMP
    PIG_RUN = '330000001577'  # 330000001577 PIGL Камера запуска 330000001577 PIGL
    PIG_RECEIVE = '1102945'  # 1102945 PIGR Камера приема 1102945 PIGR
    MARKER = '990006537229'  # 990006537229 MARK Маркер 990006537229 -
    MARKER_RING = '990006537228'  # 990006537229 MARK Маркер 990006537229 -
    MARKER_MAGN = '990006537230'  # 990006537230 MGNT Маркер магнитный 990006537230 -
    ZAVAR_BOBYSHKI = '990006537370'  # 990006537370 LUWD Заварка бобышки 990006537370 -
    ZAVAR_OKNA = '990006537234'  # 990006537234 WIWD Заварка окна 990006537234 -
    REMONT_NAKLAD = '990006537232'  # 990006537169 REPA Место ремонта 990006537169 OTHE
    METALL_CASE_START = '990006537169'  # 990006537169 REPA Металлическая упрочняющая муфта, начало 6907292 WSLB
    METALL_CASE_END = '990006537169'  # 990006537169 REPA Металлическая упрочняющая муфта, конец 6907290 WSLE
    KOMPOS_CASE_START = '6907288'  # 990006537169 REPA Композитная упрочняющая муфта, начало 6907288 СSLB
    KOMPOS_CASE_END = '6907283'  # 990006537169 REPA Композитная упрочняющая муфта, конец 6907283 СSLE
    WRONG_CONSTRUCT = '990006537239'  # 990006537170 OTHE Особенность 990006537170 -
    UNKNOWN = '990006537238'  # 990006537170 OTHE Особенность 990006537170 -
    DU1000_DU1200 = '6587147'  # 990006537170 OTHE Особенность 990006537170 -
    DU1200_DU1000 = '6587146'  # 990006537170 OTHE Особенность 990006537170 -
    DU1200_DU1400 = '6587148'  # 990006537170 OTHE Особенность 990006537170 -
    DU1400_DU1200 = '6587149'  # 990006537170 OTHE Особенность 990006537170 -
    TUBE_ARMATURE = '990006537365'  # 990006537170 OTHE Особенность 990006537170 -
    ELEMENT_OBUSTROY = '990006537364'  # 990006537170 OTHE Особенность 990006537170 -
    WATER_START = '990006911721'  # 990006537170 OTHE Пересечение с водной преградой, начало 6907276 CROSB
    WATER_END = '990006911716'  # 990006537170 OTHE Пересечение с водной преградой, конец 990006911717 CROSE
    FLANETS = '990006911715'  # 990006537170 OTHE Соединение трубных секций 990006912121 FLANG
    OTVOD_VREZKA = '990006537240'  # 990006537240 OFFT Отвод-врезка 990006537240 -
    CASE_START = '990006537242'  # 990006537242 CASB Патрон начало 990006537242 -
    CASE_END = '990006537241'  # 990006537173 CASE Патрон конец 990006537173 -
    PRIGRUZ_RING = '990006537245'  # 990007412848 ANCH Пригруз 990007412848 -
    PRIGRUZ_START = '990006537243'  # 990007412848 ANCH Пригруз 990007412848 -
    PRIGRUZ_END = '990006537244'  # 990007412848 ANCH Пригруз 990007412848 -
    TROYNIK = '990007183153'  # 990007183153 TEE Тройник 990007183153 -
    WALL_THICK = '990006537248'  # 990006537247 WELD Изменение толщины стенки трубы 990006537248 CHWT
    TURN_START = '990006537252'  # 990006537247 WELD Отвод (поворот) начало 990006537252 BENB
    TURN_END = '990006537250'  # 990006537247 WELD Отвод (поворот) конец 990006537250 BENE
    TURN_SEGM_START = '990006537251'  # 990006537247 WELD Отвод (поворот) начало 990006537252 BENB
    TURN_SEGM_END = '990006537249'  # 990006537247 WELD Отвод (поворот) конец 990006537250 BENE
    TURN_SEGM = '990007182542'  # 990006537247 WELD Отвод сегментный 990007182541 BENE
    WELD = '990006537247'  # 990006537247 WELD Шов кольцевой 990006537247 -
    ZADVIZHKA = '990007183184'  # 240004546504 VALV Кран 240004546504 -
    VALVE = '110000924874'  # 240004546504 VALV Кран 240004546504 -

==> oeg_infotech-1.5-py2-none-any.whl: oeg_infotech/codes/feature.py <==
# coding: utf-8
"""Pipeline features."""


class Feature:  # pylint: disable=no-init,too-few-public-methods
    """Codes for detected features."""

    ANOMALY = '990006537198'  # 990006537148 ANOM Аномалия 990006537148 OTHE
    NESVAR_STYK = '990006537195'  # 990006537148 ANOM Несваренный стык патрона 990006537195 UWCA
    POTERYA_CONTACTA = '990006548776'  # 990006537148 ANOM Аномалия 990006537148 OTHE
    EXCENTR_CASE = '990006537194'  # 990006537148 ANOM Эксцентричный патрон 990006537194 EXCA
    ANOMAL_KOLTSEVOGO = '990006537187'  # 990006537148 ANOM Аномалия кольцевого шва 990006537187 GWAN
    ANOMAL_OBLTSOVKI = '990006537186'  # 990006537148 ANOM Аномалия кольцевого шва 990006537187 GWAN
    CORROZ_KOLTSEVOGO = '990006537185'  # 990006537148 ANOM Аномалия кольцевого шва 990006537187 GWAN
    NEPROVAR_UTYAZH = '990006537184'  # 990006537148 ANOM Аномалия кольцевого шва 990006537187 GWAN
    NO_USILEN_KOLTSEVOGO = '990008404344'  # 990006537148 ANOM Аномалия кольцевого шва 990006537187 GWAN
    PODKLAD_KOLTSO = '990006548775'  # 330000002264 OTHE Другое 330000002264 -
    PODREZ = '990006537148'  # 990006537148 ANOM Аномалия кольцевого шва 990006537187 GWAN
    PRAVKA_KROMOK = '990006548774'  # 990006537148 ANOM Аномалия кольцевого шва 990006537187 GWAN
    PROVIS_KORNYA = '990007322160'  # 990006537148 ANOM Аномалия кольцевого шва 990006537187 GWAN
    SMESCHENIE_KROMOK = '990007289509'  # 990006537148 ANOM Аномалия кольцевого шва 990006537187 GWAN
    VNUTRI_SHOV_DEFEKT = '6907237'  # 990006537148 ANOM Аномалия кольцевого шва 990006537187 GWAN
    PODGIB_KROMKY = '6907241'  # 990006537148 ANOM Аномалия кольцевого шва 990006537187 GWAN
    ANOMAL_PRODOLNOGO = '990006537188'  # 990006537148 ANOM Аномалия продольного шва 990006537188 LWAN
    VYSHLIFOVKA_PRODOLNOGO = '990007322148'  # 990006537148 ANOM Аномалия продольного шва 990006537188 LWAN
    FORMA_PRODOLNOGO = '990007322161'  # 990006537148 ANOM Аномалия продольного шва 990006537188 LWAN
    ANOMAL_SPIRALNOGO = '990006537189'  # 990006537148 ANOM Аномалия спирального шва 990006537189 SWAN
    VYSHLIFOVKA_SPIRALNOGO = '990007322164'  # 990006537148 ANOM Аномалия спирального шва 990006537189 SWAN
    FORMA_SPIRALNOGO = '990007322162'  # 990006537148 ANOM Аномалия спирального шва 990006537189 SWAN
    DENT = '230000190556'  # 990006537148 ANOM Вмятина 230000190556 DENT
    DENT_METAL_LOSS = '990006537191'  # 990006537148 ANOM Вмятина с дефектами потери металла 990006537191 DEML
    VNUTRYSTEN_RASSLOENIE = '990006537192'  # 990006537148 ANOM Внутристенное расслоение 990006537192 LAMI
    GOFRA = '990006537193'  # 990006537148 ANOM Гофра 990006537147 WRIN
    FACTORY_DEFEKT = '990006537199'  # 990006537148 ANOM Заводской дефект 990006537199 MIAN
    METALL_DEFEKT = '990004698865'  # 990006537148 ANOM Заводской дефект 990006537199 MIAN
    VYSHLIFOVKA = '990004698880'  # 990006537148 ANOM Вышлифовка 990004698880 GRIN
    ZONE_VERT_CRACKS = '990007322158'  # 990006537148 ANOM Зона поперечных трещин 990007322158 CSCC
    ZONE_HOR_CRACKS = '990004698849'  # 990006537148 ANOM Зона продольных трещин 990004698849 SCC
    ZONE_CORROZ = '990006537202'  # 990006537148 ANOM Кластер коррозии 990006537152 COCL
    CAVERNA = '990007289502'  # 990006537148 ANOM Коррозия 990007289504 CORR
    CORROZ = '990007289504'  # 990006537148 ANOM Коррозия 990007289504 CORR
    KANAVKA_VERT = '990004698855'  # 990006537148 ANOM Коррозия 990007289504 CORR
    METALL_LOSS = '990004698869'  # 990006537148 ANOM Коррозия 990007289504 CORR
    KANAVKA_HOR = '990004698848'  # 990006537148 ANOM Коррозия 990007289504 CORR
    POINT_CORROZ = '30000179093'  # 990006537148 ANOM Коррозия 990007289504 CORR
    MECHANICAL_DEFEKT = '3760623'  # 990006537148 ANOM Механическое повреждение 3760623 ARTD
    RANDOM_ARC = '990006537209'  # 990006537148 ANOM Случайная дуга 990006537209 ARCS
    RASSL_NO_POVERHNOST = '990006537210'  # 990006537148 ANOM Расслоение с выходом на поверхность 990006537210 LAMI
    ZAVARKA = '990006537213'  # 990006537148 ANOM Технологический дефект 240000166873 TECH
    ZAVARKA_OTVERST = '990006537212'  # 990006537148 ANOM Технологический дефект 240000166873 TECH
    TECHNOLOGY_DEFEKT = '240000166873'  # 990006537148 ANOM Технологический дефект 240000166873 TECH
    CRACK_VERT_SHOV = '990006537214'  # 990006537148 ANOM Трещина на кольцевом шве 990006537214 GWCR
    CRACK_HOR_SHOV = '990007322154'  # 990006537148 ANOM Трещина на продольном шве 990007322154 LWCR
    CRACK_SPIRAL_SHOV = '990007322159'  # 990006537148 ANOM Трещина на спиральном шве 990007322159 SWCR
    NESPLOSHNOST_PT = '990006548777'  # 990006537148 ANOM Трещиноподобный дефект 990006537159 CRAC
    CRACK_VERT = '990004698875'  # 990006537148 ANOM Трещиноподобный дефект 990006537159 CRAC
    CRACK_HOR = '990006537215'  # 990006537148 ANOM Трещиноподобный дефект 990006537159 CRAC
    OVAL = '990006537217'  # 990006537148 ANOM Овализация 990006537217 OVAL
    METALL_OUT = '990006537218'  # 990006536987 ADME Металл снаружи 990006537218 TMTM
    ISOL_STYK = '990006537366'  # 990006537366 ISOL Изоляционный стык 990006537366 -
    CURVE_INSERT = '990006537221'  # 330000002264 OTHE Другое 330000002264 -
    SEGMENT_INSERT = '990006537219'  # 330000002264 OTHE Другое 330000002264 -
    HOMUT = '990006537362'  # 990006536987 ADME Хомут 990006537362 CLAMP
    PIG_RUN = '330000001577'  # 330000001577 PIGL Камера запуска 330000001577 PIGL
    PIG_RECEIVE = '1102945'  # 1102945 PIGR Камера приема 1102945 PIGR
    MARKER = '990006537229'  # 990006537229 MARK Маркер 990006537229 -
    MARKER_RING = '990006537228'  # 990006537229 MARK Маркер 990006537229 -
    MARKER_MAGN = '990006537230'  # 990006537230 MGNT Маркер магнитный 990006537230 -
    ZAVAR_BOBYSHKI = '990006537370'  # 990006537370 LUWD Заварка бобышки 990006537370 -
    ZAVAR_OKNA = '990006537234'  # 990006537234 WIWD Заварка окна 990006537234 -
    REMONT_NAKLAD = '990006537232'  # 990006537169 REPA Место ремонта 990006537169 OTHE
    METALL_CASE_START = '990006537169'  # 990006537169 REPA Металлическая упрочняющая муфта, начало 6907292 WSLB
    METALL_CASE_END = '990006537169'  # 990006537169 REPA Металлическая упрочняющая муфта, конец 6907290 WSLE
    KOMPOS_CASE_START = '6907288'  # 990006537169 REPA Композитная упрочняющая муфта, начало 6907288 СSLB
    KOMPOS_CASE_END = '6907283'  # 990006537169 REPA Композитная упрочняющая муфта, конец 6907283 СSLE
    WRONG_CONSTRUCT = '990006537239'  # 990006537170 OTHE Особенность 990006537170 -
    UNKNOWN = '990006537238'  # 990006537170 OTHE Особенность 990006537170 -
    DU1000_DU1200 = '6587147'  # 990006537170 OTHE Особенность 990006537170 -
    DU1200_DU1000 = '6587146'  # 990006537170 OTHE Особенность 990006537170 -
    DU1200_DU1400 = '6587148'  # 990006537170 OTHE Особенность 990006537170 -
    DU1400_DU1200 = '6587149'  # 990006537170 OTHE Особенность 990006537170 -
    TUBE_ARMATURE = '990006537365'  # 990006537170 OTHE Особенность 990006537170 -
    ELEMENT_OBUSTROY = '990006537364'  # 990006537170 OTHE Особенность 990006537170 -
    WATER_START = '990006911721'  # 990006537170 OTHE Пересечение с водной преградой, начало 6907276 CROSB
    WATER_END = '990006911716'  # 990006537170 OTHE Пересечение с водной преградой, конец 990006911717 CROSE
    FLANETS = '990006911715'  # 990006537170 OTHE Соединение трубных секций 990006912121 FLANG
    OTVOD_VREZKA = '990006537240'  # 990006537240 OFFT Отвод-врезка 990006537240 -
    CASE_START = '990006537242'  # 990006537242 CASB Патрон начало 990006537242 -
    CASE_END = '990006537241'  # 990006537173 CASE Патрон конец 990006537173 -
    PRIGRUZ_RING = '990006537245'  # 990007412848 ANCH Пригруз 990007412848 -
    PRIGRUZ_START = '990006537243'  # 990007412848 ANCH Пригруз 990007412848 -
    PRIGRUZ_END = '990006537244'  # 990007412848 ANCH Пригруз 990007412848 -
    TROYNIK = '990007183153'  # 990007183153 TEE Тройник 990007183153 -
    WALL_THICK = '990006537248'  # 990006537247 WELD Изменение толщины стенки трубы 990006537248 CHWT
    TURN_START = '990006537252'  # 990006537247 WELD Отвод (поворот) начало 990006537252 BENB
    TURN_END = '990006537250'  # 990006537247 WELD Отвод (поворот) конец 990006537250 BENE
    TURN_SEGM_START = '990006537251'  # 990006537247 WELD Отвод (поворот) начало 990006537252 BENB
    TURN_SEGM_END = '990006537249'  # 990006537247 WELD Отвод (поворот) конец 990006537250 BENE
    TURN_SEGM = '990007182542'  # 990006537247 WELD Отвод сегментный 990007182541 BENE
    WELD = '990006537247'  # 990006537247 WELD Шов кольцевой 990006537247 -
    ZADVIZHKA = '990007183184'  # 240004546504 VALV Кран 240004546504 -
    VALVE = '110000924874'  # 240004546504 VALV Кран 240004546504 -
